/*
 * Author: Landon Fuller <landonf@plausiblelabs.com>
 *
 * Copyright (c) 2010 Plausible Labs Cooperative, Inc.
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#import "PLSimulator.h"

/**
 * @defgroup plsimulator_device_family Device Family Constants
 * @ingroup constants
 */

/**
 * iPhone Device Family.
 * @ingroup plsimulator_device_family
 */
NSString *PLSimulatorDeviceFamilyiPhone = @"PLSimulatorDeviceFamilyiPhone";

/**
 * iPad Device Family.
 * @ingroup plsimulator_device_family
 */
NSString *PLSimulatorDeviceFamilyiPad = @"PLSimulatorDeviceFamilyiPad";


/** 
 * Generic Plausible Simulator Exception
 * @ingroup exceptions
 */
NSString *PLSimulatorException = @"PLSimulatorException";

/** Plausible Simulator NSError Domain
 * @ingroup globals */
NSString *PLSimulatorErrorDomain = @"PLSimulatorErrorDomain";

/**
 * @internal
 
 * Return a new NSError instance using the provided information.
 *
 * @param code The error code corresponding to this error.
 * @param description A localized error description.
 * @param cause The underlying cause, if any. May be nil.
 */
NSError *plsimulator_nserror (PLSimulatorError code, NSString *description, NSError *cause) {
    NSMutableDictionary *userInfo;
    
    /* Create the userInfo dictionary */
    userInfo = [NSDictionary dictionaryWithObjectsAndKeys:
                description, NSLocalizedDescriptionKey,
                nil
                ];
    
    if (cause != nil)
        [userInfo setObject: cause forKey: NSUnderlyingErrorKey];
    
    return [NSError errorWithDomain: PLSimulatorErrorDomain code: code userInfo: userInfo];
}

/**
 * @internal
 
 * Populate an NSError instance with the provided information.
 *
 * @param error Error instance to populate. If NULL, this method returns
 * and nothing is modified.
 * @param code The error code corresponding to this error.
 * @param description A localized error description.
 * @param cause The underlying cause, if any. May be nil.
 */
void plsimulator_populate_nserror (NSError **error, PLSimulatorError code, NSString *description, NSError *cause) {
    if (error == NULL)
        return;
    
    *error = plsimulator_nserror(code, description, cause);
}